@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-#
-# Util to download a full Flickr set.
-#
+"""Main functionality of the util."""
+
 import argparse
 import errno
 import json
@@ -14,7 +13,7 @@ import sys
 import time
 from pathlib import Path
 from types import FrameType
-from typing import Any, Dict, Optional, Tuple
+from typing import Any, Dict, Optional
 
 import flickr_api as Flickr
 import yaml
@@ -27,6 +26,7 @@ from flickr_download.filename_handlers import (
     get_filename_handler,
     get_filename_handler_help,
 )
+from flickr_download.logging_utils import APIKeysRedacter
 from flickr_download.utils import get_dirname, get_full_path, get_photo_page, set_file_time
 
 CONFIG_FILE = "~/.flickr_download"
@@ -81,16 +81,16 @@ def _load_defaults() -> Dict[str, Any]:
     @return: default parameters
     """
     filename = os.path.expanduser(CONFIG_FILE)
-    logging.debug(f"Loading configuration from {filename}")
+    logging.debug("Loading configuration from %s", filename)
     try:
-        with open(filename, "r") as cfile:
+        with open(filename, "r", encoding="utf-8") as cfile:
             vals = yaml.load(cfile.read(), Loader=yaml.FullLoader)
             return vals
     except yaml.YAMLError as ex:
-        logging.warning(f"Could not parse configuration file: {ex}")
+        logging.warning("Could not parse configuration file: %s", ex)
     except IOError as ex:
         if ex.errno != errno.ENOENT:
-            logging.warning(f"Could not open configuration file: {ex}")
+            logging.warning("Could not open configuration file: %s", ex)
         else:
             logging.debug("No config file")
 
@@ -105,35 +105,6 @@ def _get_metadata_db(dirname: str) -> sqlite3.Connection:
     return conn
 
 
-def _get_size_and_suffix(photo: Photo, size_label: Optional[str]) -> Tuple[Optional[str], str]:
-    photo_size_label: Optional[str] = size_label
-    if photo.get("video"):
-        pSizes = _get_photo_sizes(photo)
-        if pSizes and "HD MP4" in pSizes:
-            photo_size_label = "HD MP4"
-        else:
-            # Fall back for old 'short videos'. This might not exist, but
-            # Photo.save() will croak on auto-detecting these old videos, so
-            #  better not download than throwing an exception...
-            photo_size_label = "Site MP4"
-        suffix = ".mp4"
-        return (photo_size_label, ".mp4")
-
-    suffix = ".jpg"
-    # Flickr returns JPEG, except for when downloading originals. The only way
-    # to find the original type it seems is through the source filename. This
-    # is not pretty...
-    if photo_size_label == "Original" or not photo_size_label:
-        pSizes = _get_photo_sizes(photo)
-        meta = pSizes and pSizes.get("Original")
-        if meta and meta["source"]:
-            ext = os.path.splitext(meta["source"])[1]
-            if ext:
-                suffix = ext
-
-    return (photo_size_label, suffix)
-
-
 def download_set(
     set_id: str,
     get_filename: FilenameHandler,
@@ -177,16 +148,16 @@ def download_list(
 
     photos = Walker(pset.getPhotos)
 
-    suffix = " ({})".format(size_label) if size_label else ""
+    suffix = f" ({size_label})" if size_label else ""
 
-    logging.info(f"Downloading {photos_title}")
+    logging.info("Downloading %s", photos_title)
     dirname = get_dirname(photos_title)
     if not os.path.exists(dirname):
         try:
             os.mkdir(dirname)
         except OSError as err:
             if err.errno == errno.ENAMETOOLONG:
-                logging.warning(f"WARNING: Truncating too long directory name: {dirname}")
+                logging.warning("WARNING: Truncating too long directory name: %s", dirname)
                 # Not the most fantastic handling here, but it is surprisingly hard to get the max
                 # length in an OS-agnostic way... Assuming that most OSes can handle at least 200
                 # chars...
@@ -239,56 +210,65 @@ def do_download_photo(
     @param save_json: save photo info as .json file
     @param metadata_db: optional metadata database to record downloads in
     """
-    orig_suffix = suffix or ""
     if metadata_db:
         if metadata_db.execute(
             "SELECT * FROM downloads WHERE photo_id = ? AND size_label = ? AND suffix = ?",
-            (photo.id, size_label or "", orig_suffix),
+            (photo.id, size_label or "", suffix),
         ).fetchone():
-            logging.info(f"Skipping download of already downloaded photo with ID: {photo.id}")
+            logging.info("Skipping download of already downloaded photo with ID: %s", photo.id)
             return
 
     fname = get_full_path(dirname, get_filename(pset, photo, suffix))
-    jsonFname = fname + ".json"
+    fname = photo._getOutputFilename(fname, size_label)
+    json_fname = fname + ".json"
 
     if not photo["loaded"]:
         # trying not trigger two calls to Photo.getInfo here, as it will if it was already loaded
         try:
             photo.load()
         except FlickrError:
-            logging.info(f"Skipping {fname}, because cannot get info from Flickr")
+            logging.info("Skipping %s, because cannot get info from Flickr", fname)
             return
 
     if save_json:
         try:
-            logging.info(f"Saving photo info: {jsonFname}")
-            jsonFile = open(jsonFname, "w")
-            jsonFile.write(json.dumps(photo, default=serialize_json, indent=2, sort_keys=True))
-            jsonFile.close()
+            if Path(json_fname).exists():
+                logging.info("Skipping %s, as it exists already", json_fname)
+            else:
+                with open(json_fname, "w", encoding="utf-8") as json_file:
+                    logging.info("Saving photo info: %s", json_fname)
+                    photo_data = photo.__dict__.copy()
+                    photo_data["exif"] = photo.getExif()
+                    json_file.write(
+                        json.dumps(photo_data, default=serialize_json, indent=2, sort_keys=True)
+                    )
         except Exception:
-            logging.warning("Trouble saving photo info:", sys.exc_info()[0])
+            logging.warning("Trouble saving photo info: %s", sys.exc_info()[0])
 
-    (photo_size_label, suffix) = _get_size_and_suffix(photo, size_label)
-    if suffix:
-        fname += suffix
+    if not size_label and photo._getLargestSizeLabel() == "Video Player":
+        # For old videos there doesn't seem to be an actual video url
+        # available. The largest video size ends up being a SWF video player,
+        # and it's the SWF that'll be downloaded...
+        logging.error("Video not available for: %s", get_photo_page(photo))
+        return
 
     if os.path.exists(fname):
         # TODO: Ideally we should check for file size / md5 here
         # to handle failed downloads.
-        logging.info(f"Skipping {fname}, as it exists already")
+        logging.info("Skipping %s, as it exists already", fname)
         return
 
-    logging.info(f"Saving: {fname} ({get_photo_page(photo)})")
+    logging.info("Saving: %s (%s)", fname, get_photo_page(photo))
     if skip_download:
         return
 
     try:
-        photo.save(fname, photo_size_label)
+        photo.save(fname, size_label)
     except IOError as ex:
-        logging.error(f"IO error saving photo: {ex}")
+        logging.error("IO error saving photo: %s", ex)
         return
     except FlickrError as ex:
-        logging.error(f"Flickr error saving photo: {ex}")
+        logging.error("Flickr error saving photo: %s", ex)
         return
 
     # Set file times to when the photo was taken
@@ -296,7 +276,7 @@ def do_download_photo(
 
     if metadata_db:
         metadata_db.execute(
-            "INSERT INTO downloads VALUES (?, ?, ?)", (photo.id, size_label or "", orig_suffix)
+            "INSERT INTO downloads VALUES (?, ?, ?)", (photo.id, size_label or "", suffix)
         )
         metadata_db.commit()
 
@@ -317,11 +297,12 @@ def download_photo(
     @param save_json: save photo info as .json file
     """
     photo = Flickr.Photo(id=photo_id)
-    suffix = " ({})".format(size_label) if size_label else ""
+    suffix = f" ({size_label})" if size_label else ""
     do_download_photo(".", None, photo, size_label, suffix, get_filename, skip_download, save_json)
 
 
 def find_user(userid: str) -> Person:
+    """Tries to find the Person object for a given user string."""
     if (
         userid.startswith("https://")
         or userid.startswith("www.flickr.com")
@@ -351,7 +332,7 @@ def download_user(
     @param save_json: save photo info as .json file
     """
     user = find_user(username)
-    photosets = Walker(user.getPhotosets)
+    photosets = Walker(user.getPhotosets)  # pylint: disable=E1101
     for photoset in photosets:
         download_set(photoset.id, get_filename, size_label, skip_download, save_json)
 
@@ -384,32 +365,34 @@ def print_sets(username: str) -> None:
     @param username: the name of the user
     """
     user = find_user(username)
-    photosets = Walker(user.getPhotosets)
-    for set in photosets:
-        print(f"{set.id} - {set.title}")
+    photosets = Walker(user.getPhotosets)  # pylint: disable=E1101
+    for photoset in photosets:
+        print(f"{photoset.id} - {photoset.title}")
 
 
 def get_cache(path: str) -> SimpleCache:
+    """Loads the cache from disk, or returns an empty one if not found."""
     cache = SimpleCache(max_entries=20000, timeout=3600)
     cache_path = Path(path)
     if not cache_path.exists():
         return cache
 
     with cache_path.open("rb") as handle:
-        db = pickle.load(handle)
-        cache.storage = db["storage"]
-        logging.debug(f"Cache loaded from: {cache_path.resolve()}")
-        cache.expire_info = db["expire_info"]
+        database = pickle.load(handle)
+        cache.storage = database["storage"]
+        logging.debug("Cache loaded from: %s", cache_path.resolve())
+        cache.expire_info = database["expire_info"]
         return cache
 
 
 def save_cache(path: str, cache: SimpleCache) -> bool:
-    db = {"storage": cache.storage, "expire_info": cache.expire_info}
+    """Saves the cache to disk."""
+    database = {"storage": cache.storage, "expire_info": cache.expire_info}
     cache_path = Path(path)
     with cache_path.open("wb") as handle:
-        pickle.dump(db, handle, protocol=pickle.HIGHEST_PROTOCOL)
+        pickle.dump(database, handle, protocol=pickle.HIGHEST_PROTOCOL)
 
-    logging.debug(f"Cache saved to {cache_path.resolve()}")
+    logging.debug("Cache saved to %s", cache_path.resolve())
     return True
 
 
@@ -436,9 +419,10 @@ def _get_photo_sizes(photo: Photo) -> Dict[str, Any]:
             return photo.getSizes()
         except FlickrError as ex:
             logging.warning(
-                f"Flickr error getting photo size: {ex}, "
-                f"attempt: #{attempt}, "
-                f"attempts left: {(API_RETRIES - attempt)}"
+                "Flickr error getting photo size: %s, attempt: #%d, attempts left: %d",
+                ex,
+                attempt,
+                API_RETRIES - attempt,
             )
             time.sleep(1)
             if attempt >= API_RETRIES:
@@ -448,7 +432,11 @@ def _get_photo_sizes(photo: Photo) -> Dict[str, Any]:
 
 
 def main() -> int:
+    """Main entry point."""
     logging.basicConfig(level=logging.INFO)
+    for handler in logging.root.handlers:
+        handler.setFormatter(APIKeysRedacter(handler.formatter))
+
     parser = argparse.ArgumentParser(
         formatter_class=argparse.RawTextHelpFormatter,
         description="Downloads one or more Flickr photo sets.\n"
@@ -537,15 +525,13 @@ def main() -> int:
         help="Store information about downloads in a metadata file (helps with retrying downloads)",
     )
     parser.add_argument("-v", "--verbose", action="store_true", help="Turns on verbose logging")
-    parser.add_argument("--version", action="store_true", help="Lists the version of the tool")
+    parser.add_argument(
+        "--version", action="version", version=__version__, help="Lists the version of the tool"
+    )
     parser.set_defaults(**_load_defaults())
 
     args = parser.parse_args()
 
-    if args.version:
-        print(__version__)
-        return 0
-
     if args.verbose:
         logging.getLogger().setLevel(logging.DEBUG)
 
@@ -554,10 +540,10 @@ def main() -> int:
         cache = get_cache(args.cache)
         Flickr.enable_cache(cache)
 
-        def signal_handler(signal: int, frame: Optional[FrameType]) -> Any:
-            logging.debug(f"Hit signal handler for signal {signal}")
+        def signal_handler(sig: int, _: Optional[FrameType]) -> Any:
+            logging.debug("Hit signal handler for signal %s", sig)
             save_cache(args.cache, cache)
-            sys.exit(signal)
+            sys.exit(sig)
 
         signal.signal(signal.SIGINT, signal_handler)
 
